==> ec2-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/SubnetAttributes.java <==
package software.amazon.awscdk.services.ec2;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:23:14.080Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface SubnetAttributes extends software.amazon.jsii.JsiiSerializable {

    /**
     * The Availability Zone the subnet is located in.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getAvailabilityZone();

    /**
     * The subnetId for this particular subnet.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getSubnetId();

    /**
     * The ID of the route table for this particular subnet.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getRouteTableId();

    /**
     * @return a {@link Builder} of {@link SubnetAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SubnetAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private java.lang.String availabilityZone;
        private java.lang.String subnetId;
        private java.lang.String routeTableId;

        /**
         * Sets the value of AvailabilityZone
         * @param availabilityZone The Availability Zone the subnet is located in. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder availabilityZone(java.lang.String availabilityZone) {
            this.availabilityZone = availabilityZone;
            return this;
        }

        /**
         * Sets the value of SubnetId
         * @param subnetId The subnetId for this particular subnet. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder subnetId(java.lang.String subnetId) {
            this.subnetId = subnetId;
            return this;
        }

        /**
         * Sets the value of RouteTableId
         * @param routeTableId The ID of the route table for this particular subnet.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder routeTableId(java.lang.String routeTableId) {
            this.routeTableId = routeTableId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SubnetAttributes}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public SubnetAttributes build() {
            return new Jsii$Proxy(availabilityZone, subnetId, routeTableId);
        }
    }

    /**
     * An implementation for {@link SubnetAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SubnetAttributes {
        private final java.lang.String availabilityZone;
        private final java.lang.String subnetId;
        private final java.lang.String routeTableId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.availabilityZone = this.jsiiGet("availabilityZone", java.lang.String.class);
            this.subnetId = this.jsiiGet("subnetId", java.lang.String.class);
            this.routeTableId = this.jsiiGet("routeTableId", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.String availabilityZone, java.lang.String subnetId, java.lang.String routeTableId) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.availabilityZone = java.util.Objects.requireNonNull(availabilityZone, "availabilityZone is required");
            this.subnetId = java.util.Objects.requireNonNull(subnetId, "subnetId is required");
            this.routeTableId = routeTableId;
        }

        @Override
        public java.lang.String getAvailabilityZone() {
            return this.availabilityZone;
        }

        @Override
        public java.lang.String getSubnetId() {
            return this.subnetId;
        }

        @Override
        public java.lang.String getRouteTableId() {
            return this.routeTableId;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("availabilityZone", om.valueToTree(this.getAvailabilityZone()));
            obj.set("subnetId", om.valueToTree(this.getSubnetId()));
            if (this.getRouteTableId() != null) {
                obj.set("routeTableId", om.valueToTree(this.getRouteTableId()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SubnetAttributes.Jsii$Proxy that = (SubnetAttributes.Jsii$Proxy) o;

            if (!availabilityZone.equals(that.availabilityZone)) return false;
            if (!subnetId.equals(that.subnetId)) return false;
            return this.routeTableId != null ? this.routeTableId.equals(that.routeTableId) : that.routeTableId == null;
        }

        @Override
        public int hashCode() {
            int result = this.availabilityZone.hashCode();
            result = 31 * result + (this.subnetId.hashCode());
            result = 31 * result + (this.routeTableId != null ? this.routeTableId.hashCode() : 0);
            return result;
        }
    }
}

==> ec2-1.16.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/SubnetAttributes.java <==
package software.amazon.awscdk.services.ec2;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.2 (build faba0be)", date = "2019-11-11T17:17:50.817Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.SubnetAttributes")
@software.amazon.jsii.Jsii.Proxy(SubnetAttributes.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface SubnetAttributes extends software.amazon.jsii.JsiiSerializable {

    /**
     * The Availability Zone the subnet is located in.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getAvailabilityZone();

    /**
     * The subnetId for this particular subnet.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getSubnetId();

    /**
     * The ID of the route table for this particular subnet.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default java.lang.String getRouteTableId() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link SubnetAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SubnetAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private java.lang.String availabilityZone;
        private java.lang.String subnetId;
        private java.lang.String routeTableId;

        /**
         * Sets the value of AvailabilityZone
         * @param availabilityZone The Availability Zone the subnet is located in. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder availabilityZone(java.lang.String availabilityZone) {
            this.availabilityZone = availabilityZone;
            return this;
        }

        /**
         * Sets the value of SubnetId
         * @param subnetId The subnetId for this particular subnet. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder subnetId(java.lang.String subnetId) {
            this.subnetId = subnetId;
            return this;
        }

        /**
         * Sets the value of RouteTableId
         * @param routeTableId The ID of the route table for this particular subnet.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder routeTableId(java.lang.String routeTableId) {
            this.routeTableId = routeTableId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SubnetAttributes}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public SubnetAttributes build() {
            return new Jsii$Proxy(availabilityZone, subnetId, routeTableId);
        }
    }

    /**
     * An implementation for {@link SubnetAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SubnetAttributes {
        private final java.lang.String availabilityZone;
        private final java.lang.String subnetId;
        private final java.lang.String routeTableId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.availabilityZone = this.jsiiGet("availabilityZone", java.lang.String.class);
            this.subnetId = this.jsiiGet("subnetId", java.lang.String.class);
            this.routeTableId = this.jsiiGet("routeTableId", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String availabilityZone, final java.lang.String subnetId, final java.lang.String routeTableId) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.availabilityZone = java.util.Objects.requireNonNull(availabilityZone, "availabilityZone is required");
            this.subnetId = java.util.Objects.requireNonNull(subnetId, "subnetId is required");
            this.routeTableId = routeTableId;
        }

        @Override
        public java.lang.String getAvailabilityZone() {
            return this.availabilityZone;
        }

        @Override
        public java.lang.String getSubnetId() {
            return this.subnetId;
        }

        @Override
        public java.lang.String getRouteTableId() {
            return this.routeTableId;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("availabilityZone", om.valueToTree(this.getAvailabilityZone()));
            data.set("subnetId", om.valueToTree(this.getSubnetId()));
            if (this.getRouteTableId() != null) {
                data.set("routeTableId", om.valueToTree(this.getRouteTableId()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ec2.SubnetAttributes"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SubnetAttributes.Jsii$Proxy that = (SubnetAttributes.Jsii$Proxy) o;

            if (!availabilityZone.equals(that.availabilityZone)) return false;
            if (!subnetId.equals(that.subnetId)) return false;
            return this.routeTableId != null ? this.routeTableId.equals(that.routeTableId) : that.routeTableId == null;
        }

        @Override
        public int hashCode() {
            int result = this.availabilityZone.hashCode();
            result = 31 * result + (this.subnetId.hashCode());
            result = 31 * result + (this.routeTableId != null ? this.routeTableId.hashCode() : 0);
            return result;
        }
    }
}
